Name:           certbot
Version:        2.11.1
Release:        %mkrel 1
Summary:        A free, automated certificate authority client
Group:          Development/Python
License:        ASL 2.0
URL:            https://github.com/certbot/certbot
Source0:        https://github.com/certbot/certbot/archive/v%{version}/%{name}-%{version}.tar.gz
Source10:       certbot-renew-systemd.service
Source11:       certbot-renew-systemd.timer
Source12:       certbot-sysconfig-certbot
Source13:       README.urpmi

BuildArch:      noarch

BuildRequires:  pkgconfig(python3)

# For the systemd macros
%{?systemd_requires}
BuildRequires:  pkgconfig(libsystemd)

Obsoletes:      certbot-doc < 2.8.0-2

%description
Certbot, previously the Let's Encrypt Client, is EFF's tool to obtain certs
from Let's Encrypt, and (optionally) auto-enable HTTPS on your server.
It can also act as a client for any other CA that uses the ACME protocol.

%prep
%autosetup -n %{name}-%{version} -p1
mv certbot cert
mv cert/* .

install -Dpm644 %{SOURCE13} README.urpmi


%generate_buildrequires
%pyproject_buildrequires -x docs

%build
%pyproject_wheel

# build documentation
make \
 -C docs man html
rm -rf docs/_build/html/.docinfo

%install
%pyproject_install
%pyproject_save_files %{name}

# Put the man pages in place
install -pD -t %{buildroot}%{_mandir}/man1 docs/_build/man/%{name}.1
install -pD -t %{buildroot}%{_mandir}/man7 docs/_build/man/%{name}.7
install -Dm 0644 %{SOURCE10} %{buildroot}%{_unitdir}/certbot-renew.service
install -Dm 0644 %{SOURCE11} %{buildroot}%{_unitdir}/certbot-renew.timer
install -Dm 0644 %{SOURCE12} %{buildroot}%{_sysconfdir}/sysconfig/certbot

%check
#pytest
# Make sure the scripts use the expected python versions
#grep -q %{__python3} %{buildroot}%{_bindir}/certbot

%preun
%systemd_preun certbot-renew.timer

%files -f %{pyproject_files}
%license LICENSE.txt
%doc README.rst CHANGELOG.md README.urpmi
%doc docs/_build/html/
%{_bindir}/%{name}
# project uses old letsencrypt dirs for compatibility
%ghost %dir %{_sysconfdir}/letsencrypt
%ghost %dir %{_sharedstatedir}/letsencrypt
%ghost %dir %{_logdir}/letsencrypt
%config %{_sysconfdir}/sysconfig/certbot
%{_unitdir}/certbot-renew.service
%{_unitdir}/certbot-renew.timer
%{_mandir}/man*/%{name}.*


%changelog
* Sat Mar 08 2025 papoteur <papoteur> 2.11.1-1.mga10
+ Revision: 2162060
- new version 2.11.1
- remove config files for documentation

* Fri Dec 27 2024 papoteur <papoteur> 2.11.0-2.mga10
+ Revision: 2130398
- add and use pytest

* Mon Jun 10 2024 kekepower <kekepower> 2.11.0-1.mga10
+ Revision: 2072430
- Update to version 2.11.0

* Sat Jan 20 2024 wally <wally> 2.8.0-2.mga10
+ Revision: 2032479
- update intersphinx inventories for doc build
- rebuild for py3.12
- use pyproject rpm macros
- drop separate doc pkg

* Wed Dec 06 2023 kekepower <kekepower> 2.8.0-1.mga10
+ Revision: 2013673
- Update to version 2.8.0

* Thu Nov 02 2023 kekepower <kekepower> 2.7.4-1.mga10
+ Revision: 2003547
- Update to version 2.7.4

* Fri Oct 27 2023 kekepower <kekepower> 2.7.3-1.mga10
+ Revision: 2002061
- Update to version 2.7.3

* Fri Oct 20 2023 kekepower <kekepower> 2.7.2-1.mga10
+ Revision: 1999650
- Update to version 2.7.2

* Tue Oct 10 2023 kekepower <kekepower> 2.7.1-1.mga10
+ Revision: 1994169
- Update to version 2.7.1

* Mon Oct 09 2023 kekepower <kekepower> 2.7.0-1.mga10
+ Revision: 1993759
- Update to version 2.7.0

* Tue Aug 29 2023 kekepower <kekepower> 2.6.0-1.mga10
+ Revision: 1981050
- Update to version 2.6.0

* Wed Feb 15 2023 kekepower <kekepower> 2.3.0-1.mga9
+ Revision: 1942744
- Update to version 2.3.0

* Wed Jan 25 2023 kekepower <kekepower> 2.2.0-1.mga9
+ Revision: 1936009
- Update to version 2.2.0

* Thu Dec 15 2022 kekepower <kekepower> 2.1.1-1.mga9
+ Revision: 1923306
- Update to version 2.1.1

* Thu Dec 08 2022 kekepower <kekepower> 2.1.0-1.mga9
+ Revision: 1919302
- Update to version 2.1.0

* Wed Nov 23 2022 kekepower <kekepower> 2.0.0-1.mga9
+ Revision: 1910467
- Update to version 2.0.0

* Fri Nov 11 2022 kekepower <kekepower> 1.32.0-1.mga9
+ Revision: 1905468
- Update to version 1.32.0

* Wed Oct 05 2022 kekepower <kekepower> 1.31.0-1.mga9
+ Revision: 1894884
- Update to version 1.31.0

* Fri Sep 09 2022 kekepower <kekepower> 1.30.0-1.mga9
+ Revision: 1886223
- Update to version 1.30.0

* Thu Jul 07 2022 kekepower <kekepower> 1.29.0-1.mga9
+ Revision: 1867920
- Update to version 1.29.0

* Fri Jun 10 2022 kekepower <kekepower> 1.28.0-1.mga9
+ Revision: 1863825
- Update to version 1.28.0

* Wed May 04 2022 kekepower <kekepower> 1.27.0-1.mga9
+ Revision: 1856075
- Update to version 1.27.0

* Wed Apr 06 2022 kekepower <kekepower> 1.26.0-1.mga9
+ Revision: 1846276
- Update to version 1.26.0

* Thu Mar 17 2022 kekepower <kekepower> 1.25.0-1.mga9
+ Revision: 1797242
- Update to version 1.25.0

* Wed Mar 02 2022 kekepower <kekepower> 1.24.0-1.mga9
+ Revision: 1787724
- Update to version 1.24.0

* Thu Feb 10 2022 kekepower <kekepower> 1.23.0-1.mga9
+ Revision: 1772795
- Update to version 1.23.0

* Wed Dec 08 2021 kekepower <kekepower> 1.22.0-1.mga9
+ Revision: 1761148
- Update to version 1.22.0

* Thu Nov 04 2021 kekepower <kekepower> 1.21.0-1.mga9
+ Revision: 1753866
- Update to version 1.21.0

* Thu Oct 07 2021 kekepower <kekepower> 1.20.0-1.mga9
+ Revision: 1749958
- Update to version 1.20.0

* Sun Sep 12 2021 kekepower <kekepower> 1.19.0-1.mga9
+ Revision: 1745225
- Update to version 1.19.0

* Wed Aug 04 2021 kekepower <kekepower> 1.18.0-1.mga9
+ Revision: 1739242
- Update to version 1.18.0

* Tue Jul 06 2021 kekepower <kekepower> 1.17.0-1.mga9
+ Revision: 1735026
- Update to version 1.17.0

* Wed Jun 02 2021 kekepower <kekepower> 1.16.0-1.mga9
+ Revision: 1729378
- Update to version 1.16.0

* Wed May 05 2021 kekepower <kekepower> 1.15.0-1.mga9
+ Revision: 1721450
- Update to version 1.15.0

* Sat Apr 10 2021 kekepower <kekepower> 1.14.0-1.mga9
+ Revision: 1714461
- Update to version 1.14.0

* Thu Mar 04 2021 kekepower <kekepower> 1.13.0-1.mga9
+ Revision: 1697821
- Update to version 1.13.0

* Thu Feb 25 2021 kekepower <kekepower> 1.12.0-1.mga9
+ Revision: 1691071
- Add upstream patch to build docs
- Update to version 1.12.0

* Thu Dec 03 2020 kekepower <kekepower> 1.10.1-1.mga8
+ Revision: 1652273
- Update to version 1.10.1

* Wed Dec 02 2020 kekepower <kekepower> 1.10.0-1.mga8
+ Revision: 1651557
- Update to version 1.10.0

* Wed Oct 07 2020 kekepower <kekepower> 1.9.0-1.mga8
+ Revision: 1632556
- Update to version 1.9.0

* Tue Sep 08 2020 kekepower <kekepower> 1.8.0-1.mga8
+ Revision: 1623703
- Update to version 1.8.0

* Wed Aug 05 2020 kekepower <kekepower> 1.7.0-1.mga8
+ Revision: 1611243
- Update to version 1.7.0

* Wed Jul 08 2020 kekepower <kekepower> 1.6.0-1.mga8
+ Revision: 1602921
- Update to version 1.6.0

* Mon Jun 08 2020 kekepower <kekepower> 1.5.0-1.mga8
+ Revision: 1591058
- Update to version 1.5.0

* Tue May 19 2020 ovitters <ovitters> 1.4.0-1.mga8
+ Revision: 1586170
- require the right acme version
+ kekepower <kekepower>
- Update to version 1.4.0

* Thu Mar 05 2020 kekepower <kekepower> 1.3.0-1.mga8
+ Revision: 1554146
- Fix rel
- Update to version 1.3.0

* Thu Feb 20 2020 umeabot <umeabot> 1.2.0-2.mga8
+ Revision: 1546962
- Mageia 8 Mass Rebuild

* Thu Feb 06 2020 kekepower <kekepower> 1.2.0-1.mga8
+ Revision: 1487346
- Update to version 1.2.0

* Wed Jan 22 2020 kekepower <kekepower> 1.1.0-1.mga8
+ Revision: 1482112
- Update to version 1.1.0

* Sun Dec 08 2019 guillomovitch <guillomovitch> 1.0.0-1.mga8
+ Revision: 1465168
- new version 1.0.0

* Wed Nov 06 2019 kekepower <kekepower> 0.40.1-1.mga8
+ Revision: 1458319
- Update to version 0.40.1

* Sat Oct 05 2019 guillomovitch <guillomovitch> 0.39.0-1.mga8
+ Revision: 1449738
- new version 0.39
+ kekepower <kekepower>
- Update to version 0.38.0

* Thu Aug 22 2019 kekepower <kekepower> 0.37.2-1.mga8
+ Revision: 1431281
- Update to version 0.37.2

* Fri Aug 09 2019 kekepower <kekepower> 0.37.1-1.mga8
+ Revision: 1428328
- Update to version 0.37.1

* Thu Aug 08 2019 kekepower <kekepower> 0.37.0-1.mga8
+ Revision: 1428236
- Update to version 0.37.0
+ guillomovitch <guillomovitch>
- new version 0.36.0

* Sun Jun 30 2019 kekepower <kekepower> 0.35.1-1.mga8
+ Revision: 1416417
- Update to version 0.35.1

* Wed May 08 2019 kekepower <kekepower> 0.34.2-1.mga7
+ Revision: 1396647
- Update to version 0.34.2

* Sat Apr 06 2019 kekepower <kekepower> 0.33.1-1.mga7
+ Revision: 1386298
- Update to version 0.33.1

* Thu Apr 04 2019 kekepower <kekepower> 0.33.0-1.mga7
+ Revision: 1385652
- Update to version 0.33.0

* Thu Mar 07 2019 kekepower <kekepower> 0.32.0-1.mga7
+ Revision: 1372559
- BR python3dist(pyyaml)
- BR python3dist(pytest)
- Update to version 0.32.0

* Fri Feb 08 2019 kekepower <kekepower> 0.31.0-1.mga7
+ Revision: 1364093
- Update to version 0.31.0

* Fri Jan 25 2019 kekepower <kekepower> 0.30.2-1.mga7
+ Revision: 1360697
- Update to version 0.30.2

* Fri Jan 25 2019 kekepower <kekepower> 0.30.1-1.mga7
+ Revision: 1360594
- Update to version 0.30.1

* Mon Jan 07 2019 kekepower <kekepower> 0.30.0-3.mga7
+ Revision: 1350999
- Fix Requires for python-zope-*

* Mon Jan 07 2019 kekepower <kekepower> 0.30.0-2.mga7
+ Revision: 1350768
- Add patch to use sphinx-build-3
- Switch to python3dist()
- Rebuild for Python 3.7

* Thu Jan 03 2019 kekepower <kekepower> 0.30.0-1.mga7
+ Revision: 1348759
- Update to version 0.30.0

* Sun Dec 30 2018 kekepower <kekepower> 0.29.1-2.mga7
+ Revision: 1347216
- Update to version 0.29.1

* Fri Dec 14 2018 zezinho <zezinho> 0.28.0-2.mga7
+ Revision: 1341163
- added requires on python3-pyasn1

* Thu Nov 08 2018 guillomovitch <guillomovitch> 0.28.0-1.mga7
+ Revision: 1329023
- new version 0.28.0

* Thu Sep 20 2018 umeabot <umeabot> 0.27.1-2.mga7
+ Revision: 1277796
- Mageia 7 Mass Rebuild

* Sat Sep 08 2018 guillomovitch <guillomovitch> 0.27.1-1.mga7
+ Revision: 1257845
- new version 0.27.1

* Sun Aug 19 2018 guillomovitch <guillomovitch> 0.26.1-1.mga7
+ Revision: 1252834
- new version 0.26.1

* Tue Jun 26 2018 guillomovitch <guillomovitch> 0.25.1-1.mga7
+ Revision: 1239788
- new version 0.25.1

* Sat May 05 2018 guillomovitch <guillomovitch> 0.24.0-1.mga7
+ Revision: 1226369
- new version 0.24.0

* Wed Mar 14 2018 guillomovitch <guillomovitch> 0.22.0-1.mga7
+ Revision: 1209543
- new version 0.22

* Thu Feb 08 2018 guillomovitch <guillomovitch> 0.21.1-1.mga7
+ Revision: 1199769
- new version 0.21.1

* Tue Dec 12 2017 mitya <mitya> 0.20.0-1.mga7
+ Revision: 1182273
- New version 0.20.0

* Sun Nov 05 2017 mitya <mitya> 0.19.0-1.mga7
+ Revision: 1175971
- New version 0.19.0

* Sat Aug 05 2017 pterjan <pterjan> 0.14.2-3.mga7
+ Revision: 1135194
- Rebuild for python 3.6

* Thu Jun 08 2017 mitya <mitya> 0.14.2-2.mga6
+ Revision: 1107351
- fix BRs for systemd macro
- README.urpmi: s/Fedora/Mageia/

* Sat May 27 2017 mitya <mitya> 0.14.2-1.mga6
+ Revision: 1105149
- New version 0.14.2

* Wed May 24 2017 mitya <mitya> 0.14.1-2.mga6
+ Revision: 1104398
- remove unneeded %%post
- added %%preun

* Wed May 24 2017 mitya <mitya> 0.14.1-1.mga6
+ Revision: 1104377
- Mageify
- build mans & docs
- imported package certbot


* Thu May 18 2017 James Hogarth <james.hogarth@gmail.com> - 0.14.1-3
- Further tweaks after upstream feedback
- On F26+ use python3

* Wed May 17 2017 James Hogarth <james.hogarth@gmail.com> - 0.14.1-2
- Tweaks to the renew service bz#1444814

* Tue May 16 2017 James Hogarth <james.hogarth@gmail.com> - 0.14.1-1
- Update to 0.14.1

* Fri May 12 2017 James Hogarth <james.hogarth@gmail.com> - 0.14.0-1
- Update to 0.14.0
- Fix for bz#1444814

* Fri Apr 28 2017 James Hogarth <james.hogarth@gmail.com> - 0.13.0-2
- Incorrect target for timer

* Wed Apr 19 2017 James Hogarth <james.hogarth@gmail.com> - 0.13.0-1
* Update to 0.13.0
- Timer tweaks bz#1441846
* Tue Mar 07 2017 James Hogarth <james.hogarth@gmail.com> - 0.12.0-4
- Up the timer to daily at the request of upstream
* Mon Mar 06 2017 James Hogarth <james.hogarth@gmail.com> - 0.12.0-3
- Label the certificates generated by certbot with correct selinux context
- Include optional timer for automated renewal
* Mon Mar 06 2017 James Hogarth <james.hogarth@gmail.com> - 0.12.0-2
- upstream request not to use py3 yet so switch to py2 for default
- include a py3 option for testing
* Fri Mar 03 2017 James Hogarth <james.hogarth@gmail.com> - 0.12.0-1
- update to 0.12.0
* Fri Feb 17 2017 James Hogarth <james.hogarth@gmail.com> - 0.11.1-4
- change to python3 now certbot supports it
* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.11.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild
* Sat Feb 04 2017 James Hogarth <james.hogarth@gmail.com> - 0.11.1-2
- parsedatetime needs future but doesn't declare it
* Sat Feb 04 2017 James Hogarth <james.hogarth@gmail.com> - 0.11.1-1
- Upgrade to 0.11.1
* Thu Jan 05 2017 Adam Williamson <awilliam@redhat.com> - 0.9.3-2
- Doc generation no longer needs sphinxcontrib-programoutput
- Work around Python dep generator dependency problem (#1410631)
* Fri Oct 14 2016 Nick Bebout <nb@fedoraproject.org> - 0.9.3-1
- Update to 0.9.3
* Thu Oct 13 2016 Nick Bebout <nb@fedoraproject.org> - 0.9.2-1
- Update to 0.9.2
* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.1-3
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages
* Wed Jul 06 2016 Robert Buchholz <rbu@fedoraproject.org> - 0.8.1-2
- Remove sed-replace that changes help output and code behavior, closes #1348391
* Wed Jun 15 2016 Nick Bebout <nb@fedoraproject.org> - 0.8.1-1
- Update to 0.8.1
* Fri Jun 03 2016 james <james.hogarth@gmail.com> - 0.8.0-1
- update to 0.8.0 release
* Tue May 31 2016 James Hogarth <james.hogarth@gmail.com> - 0.7.0-1
- Update to 0.7.0
* Thu May 12 2016 Nick Bebout <nb@fedoraproject.org> - 0.6.0-2
- Bump release to 2 since 1.0devXXX is greater than 1
* Thu May 12 2016 Nick Bebout <nb@fedoraproject.org> - 0.6.0-1
- Update to 0.6.0
* Thu May 12 2016 James Hogarth <james.hogarth@gmail.com> - 0.6.0-1.0dev0git41f347d
- Update with compatibility symlink requested from upstream 
- Update with fixes from review
* Sun May 08 2016 James Hogarth <james.hogarth@gmail.com> - 0.6.0-0.0dev0git38d7503
- Upgrade to 0.6.0 dev snapshot
- Rename to certbot to match upstream rename
* Wed Apr 06 2016 Nick Bebout <nb@fedoraproject.org> - 0.5.0-1
- Upgrade to 0.5.0
* Sat Mar 05 2016 Robert Buchholz <rbu@fedoraproject.org> - 0.4.2-3
- Package does not require python-werkzeug anymore, upstream #2453
* Fri Mar 04 2016 Robert Buchholz <rbu@fedoraproject.org> - 0.4.2-2
- Fix build on EL7 where no newer setuptools is available
* Fri Mar 04 2016 Robert Buchholz <rbu@fedoraproject.org> - 0.4.2-1
- Upgrade to 0.4.2
* Tue Mar 1 2016 Nick Le Mouton <nick@noodles.net.nz> - 0.4.1-1
- Update to 0.4.1
* Thu Feb 11 2016 Nick Bebout <nb@fedoraproject.org> - 0.4.0-1
- Update to 0.4.0
* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild
* Thu Jan 28 2016 Nick Bebout <nb@fedoraproject.org> - 0.3.0-1
- Update to 0.3.0
* Sat Jan 23 2016 Robert Buchholz <rbu@fedoraproject.org> - 0.2.0-4
- Use acme dependency version consistently and add psutil min version
* Fri Jan 22 2016 Nick Bebout <nb@fedoraproject.org> - 0.2.0-3
- Update the configargparse version in other places
* Fri Jan 22 2016 Nick Bebout <nb@fedoraproject.org> - 0.2.0-2
- Update python-configargparse version requirement
* Thu Jan 21 2016 Nick Bebout <nb@fedoraproject.org> - 0.2.0-1
- Apache plugin support for non-Debian based systems
- Relaxed PyOpenSSL version requirements
- Resolves issues with the Apache plugin enabling redirect
- Improved error messages from the client
* Wed Dec 16 2015 Nick Bebout <nb@fedoraproject.org> - 0.1.1-2
- Fix packaging issues
* Wed Dec 16 2015 Nick Bebout <nb@fedoraproject.org> - 0.1.1-1
- fix a confusing UI path that caused some users to repeatedly renew their
- certs while experimenting with the client, in some cases hitting issuance rate limits
- numerous Apache configuration parser fixes
- avoid attempting to issue for unqualified domain names like "localhost"
- fix --webroot permission handling for non-root users
* Tue Dec 08 2015 Nick Bebout <nb@fedoraproject.org> - 0.1.0-3
- Add python-sphinx_rtd_theme build requirement
* Fri Dec 04 2015 James Hogarth <james.hogarth@gmail.com> - 0.1.0-2
- Add documentation from upstream
* Thu Dec 03 2015 James Hogarth <james.hogarth@gmail.com> - 0.1.0-1
- Update to new upstream release for the open beta
* Thu Dec 03 2015 James Hogarth <james.hogarth@gmail.com> - 0.0.0-5.dev20151123
- Add missing build requirements that slipped through
* Wed Dec 02 2015 James Hogarth <james.hogarth@gmail.com> - 0.0.0-4.dev20151123
- The python2 library should have the dependencies and not the bindir one
* Wed Dec 02 2015 James Hogarth <james.hogarth@gmail.com> - 0.0.0-3.dev20151123
- Separate out the python libraries from the application itself
- Enable python tests
* Tue Dec 01 2015 James Hogarth <james.hogarth@gmail.com> - 0.0.0-2.dev20151123
- Update spec to account for the runtime dependencies discovered
- Update spec to sit inline with current python practices
* Sun Apr 26 2015 Torrie Fischer <tdfischer@hackerbots.net> 0-1.git1d8281d.fc20
- Initial package
